import grok
from waeup.kofa.university.interfaces import IDepartment, ICertificate
from waeup.kofa.university.faculty import (
    Faculty, FacultyFactory)
from waeup.kofa.university.department import (
    Department, DepartmentFactory)
from waeup.kofa.university.certificate import (
    Certificate, CertificateFactory)


class CustomFaculty(Faculty):
    """A university faculty.
    """
    local_roles = [
        'waeup.local.DepartmentOfficer',
        'waeup.local.DepartmentManager',
        ]

class CustomFacultyFactory(FacultyFactory):
    """A factory for faculty containers.
    """

    def __call__(self, *args, **kw):
        return CustomFaculty()

    def getInterfaces(self):
        return implementedBy(CustomFaculty)

class CustomDepartment(Department):
    """A university department.
    """
    grok.implements(IDepartment)

    local_roles = [
        'waeup.local.ApplicationsManager',
        'waeup.local.DepartmentOfficer',
        'waeup.local.DepartmentManager',
        ]

class CustomDepartmentFactory(DepartmentFactory):
    """A factory for department containers.
    """

    def __call__(self, *args, **kw):
        return CustomDepartment(*args, **kw)

    def getInterfaces(self):
        """Get interfaces of objects provided by this factory.
        """
        return implementedBy(CustomDepartment)

class CustomCertificate(Certificate):
    """A certificate.
    """
    grok.implements(ICertificate)

    local_roles = [
        'waeup.local.DepartmentOfficer',
        ]

class CustomCertificateFactory(CertificateFactory):
    """A factory for certificates.
    """

    def __call__(self, *args, **kw):
        return CustomCertificate(*args, **kw)

    def getInterfaces(self):
        return implementedBy(CustomCertificate)